@@ -1,4 +1,5 @@
 # flake8: noqa
 from .jbrowse_config import JBrowseConfig, create
 from .util import  launch, create_component
-__all__ = ['JBrowseConfig', 'create', 'launch', 'create_component']
+from .dev_server import serve
+__all__ = ['JBrowseConfig', 'create', 'launch', 'create_component', 'serve']
